@@ -60,7 +60,7 @@ Fragment <- setClass(
 Motif <- setClass(
   Class = "Motif",
   slots = list(
-    data = "dgCMatrix",
+    data = "CsparseMatrix",
     pwm = "list",
     motif.names = "list",
     positions = "ANY",
@@ -268,11 +268,19 @@ CreateChromatinAssay <- function(
       FUN = AssignFragCellnames,
       cellnames = colnames(x = seurat.assay)
     )
+    # subset to cells in the assay
+    frags <- lapply(
+      X = fragments,
+      FUN = subset,
+      cells = colnames(x = seurat.assay)
+    )
    } else if (inherits(x = fragments, what = "Fragment")) {
     # single Fragment object supplied
     frags <- AssignFragCellnames(
       fragments = fragments, cellnames = colnames(x = seurat.assay)
     )
+    # subset to cells in the assay
+    frags <- subset(x = frags, cells = colnames(x = seurat.assay))
   } else {
     # path to fragment file supplied, create fragment object
     frags <- list()
@@ -449,13 +457,13 @@ CreateMotifObject <- function(
   meta.data <- SetIfNull(x = meta.data, y = data.frame())
   if (
     !(inherits(x = data, what = "matrix") |
-      inherits(x = data, what = "dgCMatrix"))
+      inherits(x = data, what = "CsparseMatrix"))
     ) {
     stop("Data must be matrix or sparse matrix class. Supplied ",
          class(x = data))
   }
   if (inherits(x = data, what = "matrix")) {
-    data <- as(Class = "dgCMatrix", object = data)
+    data <- as(Class = "CsparseMatrix", object = data)
   }
   if ((nrow(x = data) > 0) & (length(x = pwm) > 0)) {
     if (!all(names(x = pwm) == colnames(x = data))) {
@@ -789,7 +797,7 @@ SetAssayData.ChromatinAssay <- function(object, slot, new.data, ...) {
 #' motif.obj <- SeuratObject::GetAssayData(
 #'   object = atac_small[['peaks']], slot = "motifs"
 #' )
-#' SetMotifData(object = motif.obj, slot = 'data', new.data = matrix())
+#' SetMotifData(object = motif.obj, slot = 'data', new.data = matrix(1:2))
 SetMotifData.Motif <- function(object, slot, new.data, ...) {
   if (!(slot %in% slotNames(x = object))) {
     stop("slot must be one of ",
@@ -798,7 +806,7 @@ SetMotifData.Motif <- function(object, slot, new.data, ...) {
   }
   if (slot == "data") {
     if (inherits(x = new.data, what = "matrix")) {
-      new.data <- as(Class = "dgCMatrix", object = new.data)
+      new.data <- as(Class = "CsparseMatrix", object = new.data)
     }
   }
   # TODO check that new data is compatible with existing slots
@@ -816,14 +824,14 @@ SetMotifData.Motif <- function(object, slot, new.data, ...) {
 #' @concept motifs
 #' @examples
 #' SetMotifData(
-#'   object = atac_small[['peaks']], slot = 'data', new.data = matrix()
+#'   object = atac_small[['peaks']], slot = 'data', new.data = matrix(1:2)
 #' )
 #' @method SetMotifData ChromatinAssay
 SetMotifData.ChromatinAssay <- function(object, slot, new.data, ...) {
   if (slot == "data") {
     if (
       !(inherits(x = new.data, what = "matrix") |
-        inherits(x = new.data, what = "dgCMatrix"))
+        inherits(x = new.data, what = "CsparseMatrix"))
       ) {
       stop("Data must be matrix or sparse matrix class. Supplied ",
            class(x = new.data))
@@ -833,7 +841,7 @@ SetMotifData.ChromatinAssay <- function(object, slot, new.data, ...) {
            Column names in motif matrix should match row names in assay data")
     }
     if (inherits(x = new.data, what = "matrix")) {
-      new.data <- as(Class = "dgCMatrix", object = new.data)
+      new.data <- as(Class = "CsparseMatrix", object = new.data)
     }
   }
   motif.obj <- GetAssayData(object = object, slot = "motifs")
@@ -876,8 +884,6 @@ SetMotifData.Seurat <- function(object, assay = NULL, ...) {
 #' @param motifs Which motifs to retain
 #' @param ... Arguments passed to other methods
 #'
-#' @aliases subset
-#' @rdname subset.Motif
 #' @method subset Motif
 #'
 #' @seealso \code{\link[base]{subset}}
@@ -955,10 +961,7 @@ subset.ChromatinAssay <- function(
   # subset cells in Fragments objects
   frags <- Fragments(object = x)
   for (i in seq_along(along.with = frags)) {
-    frag.cells <- GetFragmentData(object = frags[[i]], slot = "cells")
-    # there can be cells in the assay that are not in the fragment object
-    keep <- names(x = frag.cells) %in% cells
-    slot(object = frags[[i]], name = "cells") <- frag.cells[keep]
+    frags[[i]] <- subset(x = frags[[i]], cells = cells)
   }
 
   # convert standard assay to ChromatinAssay
@@ -975,6 +978,38 @@ subset.ChromatinAssay <- function(
   return(chromassay)
 }
 
+#' Subset a Fragment object
+#'
+#' Returns a subset of a \code{\link{Fragment-class}} object.
+#'
+#' @param x A Fragment object
+#' @param cells Vector of cells to retain
+#' @param ... Arguments passed to other methods
+#'
+#' @method subset Fragment
+#'
+#' @importFrom fastmatch fmatch
+#' @seealso \code{\link[base]{subset}}
+#' @return Returns a subsetted \code{\link{Fragment}} object
+#' @export
+#' @concept fragments
+#' @examples
+#' fpath <- system.file("extdata", "fragments.tsv.gz", package="Signac")
+#' cells <- colnames(x = atac_small)
+#' names(x = cells) <- paste0("test_", cells)
+#' frags <- CreateFragmentObject(path = fpath, cells = cells, verbose = FALSE, tolerance = 0.5)
+#' subset(frags, head(names(cells)))
+subset.Fragment <- function(
+  x,
+  cells = NULL,
+  ...
+) {
+  frag.cells <- GetFragmentData(object = x, slot = "cells")
+  keep <- fmatch(x = names(x = frag.cells), table = cells, nomatch = 0L) > 0
+  slot(object = x, name = "cells") <- frag.cells[keep]
+  return(x)
+}
+
 #' @export
 #' @concept assay
 #' @method merge ChromatinAssay
