@@ -901,7 +901,6 @@ MatchRegionStats <- function(
     warning("Requested more features than present in supplied data.
             Returning ", n, " features")
   }
-  # features.choose <- meta.feature[choosefrom, ]
   for (i in seq_along(along.with = features.match)) {
     featmatch <- features.match[[i]]
     if (!(featmatch %in% colnames(x = query.feature))) {
@@ -918,10 +917,11 @@ MatchRegionStats <- function(
     density.estimate <- density(
       x = query.feature[[featmatch]], kernel = "gaussian", bw = 1
     )
+    mf.use <- meta.feature[!is.na(x = meta.feature[[featmatch]]), ]
     weights <- approx(
       x = density.estimate$x,
       y = density.estimate$y,
-      xout = meta.feature[[featmatch]],
+      xout = mf.use[[featmatch]],
       yright = 0.0001,
       yleft = 0.0001
     )$y
@@ -932,11 +932,11 @@ MatchRegionStats <- function(
     }
   }
   feature.select <- sample.int(
-    n = nrow(x = meta.feature),
+    n = nrow(x = mf.use),
     size = n,
     prob = feature.weights
   )
-  feature.select <- rownames(x = meta.feature)[feature.select]
+  feature.select <- rownames(x = mf.use)[feature.select]
   return(feature.select)
 }
 
@@ -1088,7 +1088,7 @@ BinaryIdentMatrix <- function(object, group.by = NULL, idents = NULL) {
   )
   colnames(x = ident.matrix) <- names(x = group.idents)
   rownames(x = ident.matrix) <- unique.groups
-  ident.matrix <- as(object = ident.matrix, Class = "dgCMatrix")
+  ident.matrix <- as(object = ident.matrix, Class = "CsparseMatrix")
   return(ident.matrix)
 }
 
@@ -2065,7 +2065,7 @@ MergeOverlappingRows <- function(
       }
       merged.mat <- Reduce(f = rbind, x = newmat)
       rownames(merged.mat) <- newmat.names
-      merged.mat <- as(object = merged.mat, Class = "dgCMatrix")
+      merged.mat <- as(object = merged.mat, Class = "CsparseMatrix")
 
       # remove rows from count matrix that were merged
       mat.rows <- seq_len(length.out = nrow(x = counts))
@@ -2105,7 +2105,7 @@ PartialMatrix <- function(tabix, regions, sep = c("-", "-"), cells = NULL) {
     )
     rownames(x = featmat) <- GRangesToString(grange = regions)
     colnames(x = featmat) <- cells
-    featmat <- as(object = featmat, Class = "dgCMatrix")
+    featmat <- as(object = featmat, Class = "CsparseMatrix")
     return(featmat)
   } else if (all(nrep == 0)) {
     # no fragments, no cells requested
@@ -2116,7 +2116,7 @@ PartialMatrix <- function(tabix, regions, sep = c("-", "-"), cells = NULL) {
       j = NULL
     )
     rownames(x = featmat) <- GRangesToString(grange = regions)
-    featmat <- as(object = featmat, Class = "dgCMatrix")
+    featmat <- as(object = featmat, Class = "CsparseMatrix")
     return(featmat)
   } else {
     # fragments detected
@@ -2138,7 +2138,7 @@ PartialMatrix <- function(tabix, regions, sep = c("-", "-"), cells = NULL) {
       j = cells.in.regions,
       x = rep(x = 1, length(x = cells.in.regions))
     )
-    featmat <- as(Class = "dgCMatrix", object = featmat)
+    featmat <- as(Class = "CsparseMatrix", object = featmat)
     rownames(x = featmat) <- all.features[1:max(feature.vec)]
     colnames(x = featmat) <- names(x = cell.lookup)[1:max(cells.in.regions)]
     # add zero columns for missing cells
@@ -2154,7 +2154,7 @@ PartialMatrix <- function(tabix, regions, sep = c("-", "-"), cells = NULL) {
         dims = c(length(x = missing.features), ncol(x = featmat))
       )
       rownames(x = null.mat) <- missing.features
-      null.mat <- as(object = null.mat, Class = "dgCMatrix")
+      null.mat <- as(object = null.mat, Class = "CsparseMatrix")
       featmat <- rbind(featmat, null.mat)
     }
     return(featmat)
@@ -2196,8 +2196,8 @@ SparseColVar <- function(x) {
 #
 # This rank matrix can then be used to calculate pearson correlation
 SparsifiedRanks <- function(X){
-  if (!inherits(x = X, what = "dgCMatrix")) {
-    X <- as(object = X, Class = "dgCMatrix")
+  if (!inherits(x = X, what = "CsparseMatrix")) {
+    X <- as(object = X, Class = "CsparseMatrix")
   }
   non_zeros_per_col <- diff(x = X@p)
   n_zeros_per_col <- nrow(x = X) - non_zeros_per_col
